@@ -1,5 +1,6 @@
 import multiprocessing
 import unittest
+from pprint import pprint
 
 import numpy
 import sklearn
@@ -19,6 +20,7 @@ class TestPredictionsUncertainty(unittest.TestCase):
         x[:, 1] = 0
         # 1st is double importance, 2nd has no importance
         y = numpy.sum(x, axis=1) + 2 * x[:, 0]
+        y[x[:, 0] < 0.2] = x[x[:, 0] < 0.2, 2]
         if is_classification:
             y = numpy.round(y, 0).astype(int)
         return DMD(x=x, y=y,
@@ -32,7 +34,7 @@ class TestPredictionsUncertainty(unittest.TestCase):
             estimator = RandomForestRegressor
 
         model = GeneralUtils.simple_imputation_pipeline(
-            estimator(random_state=0, n_jobs=multiprocessing.cpu_count() - 1, n_estimators=10))
+            estimator(random_state=0, n_jobs=multiprocessing.cpu_count() - 1, n_estimators=15))
 
         return model
 
@@ -72,10 +74,12 @@ class TestPredictionsUncertainty(unittest.TestCase):
         subset_bad_score = metric(
             y_true=new_data.target[bad], y_pred=yp[bad], **kwargs)
 
+        print(subset_bad_score, base_score, subset_good_score)
         self.assertGreater(subset_good_score, base_score)
         self.assertLess(subset_bad_score, base_score)
 
-        print(subset_bad_score, base_score, subset_good_score)
+        pprint(uncertainty_model.uncertainty_analysis(dmd_train=train))
+
 
     def test_classification_confidence(self):
         self._test(is_classification=True, method='confidence')
@@ -89,6 +93,9 @@ class TestPredictionsUncertainty(unittest.TestCase):
     def test_regression_rmse(self):
         self._test(is_classification=False, method='rmse')
 
+    def test_regression_quantile(self):
+        self._test(is_classification=False, method='quantile')
+
         # subset_bad_score = []
         # subset_good_score = []
         # for k in range(10):
